@@ -3,7 +3,6 @@ import sys
 import time
 import subprocess
 import pathlib
-from tkinter.tix import Tree
 from semver import VersionInfo
 from cement import Controller, ex
 from ..core.config import load_config
@@ -180,14 +179,14 @@ class Crawler(Controller):
 
         toolbar_width = 50
         verbose_mode = False
-
+        
         try:
-            if self.config.deploy.verbose == True:
+            if self.config['deploy']['verbose'] == True or self.app.pargs.verbose == True:
                 verbose_mode = True
         except:
-            verbose_mode = False
+            if self.app.pargs.verbose == True:
+                verbose_mode = True
 
-        verbose_mode = self.app.pargs.verbose
         input_plugin_name = self.app.pargs.plugin_name
         deploy_message = self.app.pargs.message
 
@@ -266,7 +265,6 @@ class Crawler(Controller):
                     progress = int(.10 * toolbar_width)
                     sys.stdout.write("-" * progress)
                     sys.stdout.flush()
-                    time.sleep(.5)
                 try:
                     cmd = f"""
                         cd {plugin_dir_path} &&
@@ -301,7 +299,6 @@ class Crawler(Controller):
                         progress = int(.30 * toolbar_width)
                         sys.stdout.write("-" * progress)
                         sys.stdout.flush()
-                        time.sleep(.5)
 
                 except subprocess.CalledProcessError:
                     self.app.log.error(
